//*******************************************************************************
//
//  
//  ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k
//
//                MSP430F1121A
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//       S1-->|P2.1         P2.3|-->LED1
//            |             P2.0|-->|- ACLK/8=4096Hz
//       S2-->|P1.2             |   | |BUZZER 
//            |             P2.5|-->|-

//nacisniecie przycisku S1 powoduje zapalenie diody LED1 na okolo 200ms
//nacisniecie przycisku S2 powoduje wlaczenie brzeczyka na okolo 200ms

#include  <msp430x11x2.h>

#define LED1  0x08
#define LED2  0x10  
#define S1    0x02
#define S2    0x04

#define BUZ1  0x01                      //port P2.0
#define BUZ2  0x20                      //port P2.5  


#define S1IN  (P2IN&0x02)
#define S2IN  (P1IN&0x04)

void main(void)
{ 
  WDTCTL = WDTPW + WDTHOLD;           //zatrzymaj watchdog timer
  BCSCTL1|=0x30;                      // na P2.0 sygnal ACLK/8 =4096Hz
  P2DIR &=~BUZ1;                      // P2.0 jako wejscie
  P2SEL |= BUZ1;                      // P2.0 jako wyjscie ACLK 
  P2DIR |= BUZ2;                      // P2.5 jako wyjscie
  
  P2DIR |= LED1;                      //Port P2.3 jako wyjscie
  P2OUT |= LED1;                      //dioda LED1 wylaczona
  P2DIR &=~S1;                        //port P2.1 jako wejscie                         
  P1DIR &=~S2;                        //port P1.2 jako wejscie
  for (;;)                              
  {
    unsigned int i;

   if(S1IN==0)                        //jesli nacisniety przycisk S1
       {for(i=0;i<5000;i++);          //pauza       
          if(S1IN==0)                 //sprawdz ponownie czy nacisniety S1
             {P2OUT&=~LED1;           //zapal diode LED1
              for(i=0;i<50000;i++);   //pauza   
              P2OUT|=LED1;            //zgas diode LED1
              }  
        }

    if(S2IN==0)                       //jesli nacisniety przycisk S2
       {for(i=0;i<5000;i++);          //pauza 
          if(S2IN==0)                 //sprawdz ponownie czy nacisniety S2
             {P2DIR|=BUZ1;            //wlacz brzeczyk
              for(i=0;i<50000;i++);   //pauza   
              P2DIR&=~BUZ1;           //wylacz brzeczy
              }  
        }
  }
}

